cloud_inquisitor\.plugins\.auditors
===================================

Module contents
---------------

.. automodule:: cloud_inquisitor.plugins.auditors
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::
    :maxdepth: 1

    cloudtrail
    domain_hijacking
    iam
    required_tags
    vpc_flow_logs
